==> haskell-xcffib-0.12.1-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xcffib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 xcffib
version:              0.12.1
visibility:           public
id:                   xcffib-0.12.1-LKycClcngUELpU3PXBZTww
key:                  xcffib-0.12.1-LKycClcngUELpU3PXBZTww
license:              LicenseRef-OtherLicense
maintainer:           Tycho Andersen <tycho@tycho.pizza>
author:               Tycho Andersen
homepage:             http://github.com/tych0/xcffib
synopsis:             A cffi-based python binding for X
description:          A cffi-based python binding for X, comparable to xpyb
category:             X11
abi:                  be11d106c90de67d7ae03a1e707f73a5
exposed:              True
exposed-modules:      Data.XCB.Python.Parse Data.XCB.Python.PyHelpers
import-dirs:          /usr/lib/ghc-9.0.2/site-local/xcffib-0.12.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/xcffib-0.12.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xcffib
hs-libraries:         HSxcffib-0.12.1-LKycClcngUELpU3PXBZTww
depends:
    attoparsec-0.14.4-9SQv4o2tq0k4n7CegIwza1 base-4.15.1.0
    bytestring-0.10.12.1 containers-0.6.4.1
    either-5.0.2-CESQcB8iry59WM5GQWasBQ
    filemanip-0.3.6.3-KQT0pvs2duR8fpnnmG50zM filepath-1.4.2.1
    language-python-0.5.8-BYqX2yzfzQs4sQcqOiLtNK mtl-2.2.2
    split-0.2.3.5-1ZFbiAR4sQhKaqqBevLjN8
    xcb-types-0.11.0-H1oIZ7ynRCCEg5NNKtMpx9

haddock-interfaces:   /usr/share/doc/haskell-xcffib/html/xcffib.haddock
haddock-html:         /usr/share/doc/haskell-xcffib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xcffib-0.12.1-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xcffib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 xcffib
version:              0.12.1
visibility:           public
id:                   xcffib-0.12.1-1m5OqPdu85t7WCgWnUVxuV
key:                  xcffib-0.12.1-1m5OqPdu85t7WCgWnUVxuV
license:              LicenseRef-OtherLicense
maintainer:           Tycho Andersen <tycho@tycho.pizza>
author:               Tycho Andersen
homepage:             http://github.com/tych0/xcffib
synopsis:             A cffi-based python binding for X
description:          A cffi-based python binding for X, comparable to xpyb
category:             X11
abi:                  4e40118bb5149c58187b88edcd899982
exposed:              True
exposed-modules:      Data.XCB.Python.Parse Data.XCB.Python.PyHelpers
import-dirs:          /usr/lib/ghc-9.0.2/site-local/xcffib-0.12.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/xcffib-0.12.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xcffib
hs-libraries:         HSxcffib-0.12.1-1m5OqPdu85t7WCgWnUVxuV
depends:
    attoparsec-0.14.4-BZexaHOT2692bWaZsVxn9Y base-4.15.1.0
    bytestring-0.10.12.1 containers-0.6.4.1
    either-5.0.2-CxYyO3BQUOA9PkE70dCPux
    filemanip-0.3.6.3-7Qh8v9OWP0jBCAHy2sYSAY filepath-1.4.2.1
    language-python-0.5.8-3FxAPC0pcUHmFKUVlib5G mtl-2.2.2
    split-0.2.3.5-7kO3TuLb37JGMIKrO7hYT4
    xcb-types-0.11.0-H1oIZ7ynRCCEg5NNKtMpx9

haddock-interfaces:   /usr/share/doc/haskell-xcffib/html/xcffib.haddock
haddock-html:         /usr/share/doc/haskell-xcffib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
